@@ -20,7 +20,7 @@ Usage::
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
     ```
 """
-from typing import List
+from typing import Sequence
 
 from botocore.waiter import Waiter as Boto3Waiter
 
@@ -31,7 +31,7 @@ __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
     """
 
@@ -39,20 +39,20 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         self,
         *,
         DBInstanceIdentifier: str = None,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         MaxRecords: int = None,
         Marker: str = None,
         WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
     """
 
@@ -60,12 +60,12 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         self,
         *,
         DBInstanceIdentifier: str = None,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         MaxRecords: int = None,
         Marker: str = None,
         WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
         """
